[Qa-jenkins-scm] [jenkins.debian.net] 02/03: reproducible archlinux: rebuild all of 'core' every week, rebuild all of 'extra' every month

Holger Levsen holger at moszumanska.debian.org
Fri Dec 11 13:15:47 UTC 2015


This is an automated email from the git hooks/post-receive script.

holger pushed a commit to branch master
in repository jenkins.debian.net.

commit 07e9247b6c175f1353fcd78859af1d974a97dbd5
Author: Holger Levsen <holger at layer-acht.org>
Date:   Fri Dec 11 14:14:49 2015 +0100

    reproducible archlinux: rebuild all of 'core' every week, rebuild all of 'extra' every month
---
 bin/reproducible_build_archlinux_pkg.sh | 10 ++++++++--
 1 file changed, 8 insertions(+), 2 deletions(-)

diff --git a/bin/reproducible_build_archlinux_pkg.sh b/bin/reproducible_build_archlinux_pkg.sh
index f1d7a50..eb0d8ad 100755
--- a/bin/reproducible_build_archlinux_pkg.sh
+++ b/bin/reproducible_build_archlinux_pkg.sh
@@ -56,9 +56,15 @@ choose_package() {
 	schroot --end-session -c $SESSION
 	rm $DUMMY > /dev/null
 	for REPOSITORY in core extra ; do
+		case $REPOSITORY in
+			core)	MIN_AGE=6
+				;;
+			extra)	MIN_AGE=27
+				;;
+		esac
 		for PKG in $(cat ${ARCHLINUX_PKGS}_$REPOSITORY) ; do
-			# build package if it has never build or at least a week ago
-			if [ ! -d $BASE/archlinux/$REPOSITORY/$PKG ] || [ ! -z $(find $BASE/archlinux/$REPOSITORY/ -name $PKG -mtime +6) ] ; then
+			# build package if it has never build or at least $MIN_AGE days ago
+			if [ ! -d $BASE/archlinux/$REPOSITORY/$PKG ] || [ ! -z $(find $BASE/archlinux/$REPOSITORY/ -name $PKG -mtime +$MIN_AGE) ] ; then
 				SRCPACKAGE=$PKG
 				echo "$(date -u ) - building package $PKG from '$REPOSITORY' now..."
 				# very simple locking…

-- 
Alioth's /usr/local/bin/git-commit-notice on /srv/git.debian.org/git/qa/jenkins.debian.net.git



More information about the Qa-jenkins-scm mailing list